## Mandatory environment variables

** All tools require the following environment variables to be set. These are mandatory**

>Note that these environment variables are automatically set by the platform when the tool is run. These are only required when running the tool locally for testing purposes.

| Variable           | Description                                       |
| ------------------ | ------------------------------------------------- |
| `PLATFORM_HOST`    | The host in which the platform service is running |
| `PLATFORM_PORT`    | The port in which the service is listening        |
| `PLATFORM_API_KEY` | The API key for the platform                      |
